@@ -1,25 +1,27 @@
 # ABSTRACT: Search Complex Data Structures
 package Data::Seek;
 
-use 5.10.0;
-use strict;
-use warnings;
-
 use Data::Seek::Data;
 use Data::Seek::Search;
 
-use Mo 'default';
+use Data::Object::Class;
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
-has 'cache',
-    default => 0;
+has 'cache' => (
+    is      => 'rw',
+    default => 0
+);
 
-has 'data',
-    default => sub {{}};
+has 'data' => (
+    is      => 'ro',
+    default => sub {{}}
+);
 
-has 'ignore',
-    default => 0;
+has 'ignore' => (
+    is      => 'rw',
+    default => 0
+);
 
 sub search {
     my ($self, @criteria) = @_;
@@ -75,7 +77,7 @@ Data::Seek - Search Complex Data Structures
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -92,16 +94,14 @@ version 0.05
 Data::Seek is a module for traversing complex data structures. This module
 allows you to select specific node(s) in a hierarchical data structure using a
 criteria. A criteria is an expression consisting of one or more criterion. A
-criterion is the part of the criteria that is used to select node(s) and
-sub-node(s) to be returned in the result. Data::Seek is akin to L<Data::Dpath>
-but with far fewer features, a simpler node selection syntax, and a
-non-recursive approach toward traversal which makes Data::Seek extremely fast
-and efficient. An even better reason to use Data::Seek is its ability to throw
-exception objects which explain, in detail, why a search failed. This is very
-useful internally, and externally when processing foreign data structures where
-you need to provide detailed errors explaining how to resolve the missing or
-malformed data nodes. For more information on the underlying concepts, please
-see L<Data::Seek::Concepts>.
+criterion is the part of the criteria that is used to select node(s) to be
+returned in the result. Data::Seek is akin to L<Data::Dpath> but with fewer
+features and a simple node selection syntax. Data::Seek node traversal is
+extremely fast, and it can throw exception objects which explain, in detail,
+why a search failed. This is very useful internally, and externally when
+processing foreign data structures where you need to provide detailed errors
+explaining how to resolve the missing or malformed data nodes. For more
+information on the underlying concepts, please see L<Data::Seek::Concepts>.
 
 =head1 ATTRIBUTES
 
@@ -140,8 +140,6 @@ Prepare a search object to use the supplied criteria and return a result
 object. Introspection is triggered when the result object is enacted. See
 L<Data::Seek::Search::Result> for usage information.
 
-=encoding utf8
-
 =head1 AUTHOR
 
 Al Newkirk <anewkirk@ana.io>
