@@ -1,17 +1,12 @@
 # ABSTRACT: Data::Seek Data Structure Container
 package Data::Seek::Data;
 
-use 5.10.0;
-use strict;
-use warnings;
-
-use Mo;
-
+use Data::Object::Class;
 use Hash::Flatten ();
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
-has 'object';
+has 'object', is => 'ro';
 
 sub decode {
     my $self   = shift;
@@ -39,7 +34,7 @@ Data::Seek::Data - Data::Seek Data Structure Container
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -76,8 +71,6 @@ reference.
 Uses L<Hash::Flatten> to flatten/fold the data structure returning a hash
 reference.
 
-=encoding utf8
-
 =head1 AUTHOR
 
 Al Newkirk <anewkirk@ana.io>
