@@ -1,34 +1,27 @@
 # Data::Seek Exception Class
 package Data::Seek::Exception;
 
-use 5.10.0;
-
-use strict;
-use warnings;
-
-use Mo 'builder';
-
 use Data::Dumper ();
 use Scalar::Util ();
 
+use Data::Object::Class;
+
 use overload fallback => 1, '""' => \&as_string;
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
-has 'code';
-has 'file';
-has 'line';
+has 'code', is => 'ro';
+has 'file', is => 'ro';
+has 'line', is => 'ro';
 
-has 'message',
-    builder => '_build_message';
+has 'message' => (
+    is      => 'ro',
+    default => sub { 'An exception occurred in class (' . ref(shift) . ')' },
+    lazy    => 1
+);
 
-sub _build_message {
-    sprintf 'An unknown error occurred in class (%s)',
-        ref shift
-}
-
-has 'package';
-has 'subroutine';
+has 'package',    is => 'ro';
+has 'subroutine', is => 'ro';
 
 sub as_string {
     my $self = shift;
