@@ -1,26 +1,21 @@
 # ABSTRACT: Data::Seek Invalid Node Exception Class
 package Data::Seek::Exception::NodeInvalid;
 
-use 5.10.0;
-
-use strict;
-use warnings;
-
-use Mo;
+use Data::Object::Class;
 
 extends 'Data::Seek::Exception';
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
-has 'criterion';
-has 'separator';
-has 'subject';
-has 'target';
+has 'criterion',  is => 'ro';
+has 'separator',  is => 'ro';
+has 'subject',    is => 'ro';
+has 'target',     is => 'ro';
 
-has 'was_array';
-has 'was_ending';
-has 'was_hash';
-has 'was_match';
+has 'was_array',  is => 'ro';
+has 'was_ending', is => 'ro';
+has 'was_hash',   is => 'ro';
+has 'was_match',  is => 'ro';
 
 sub _build_message {
     my $self = shift;
@@ -59,7 +54,7 @@ Data::Seek::Exception::NodeInvalid - Data::Seek Invalid Node Exception Class
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -122,8 +117,6 @@ True is the node prior to the exception being thrown was a hash reference.
 
 True is the node prior to the exception being thrown had corresponding data.
 
-=encoding utf8
-
 =head1 AUTHOR
 
 Al Newkirk <anewkirk@ana.io>
