@@ -1,26 +1,21 @@
 # ABSTRACT: Data::Seek Unknown Root Exception Class
 package Data::Seek::Exception::RootUnknown;
 
-use 5.10.0;
-
-use strict;
-use warnings;
-
-use Mo;
+use Data::Object::Class;
 
 extends 'Data::Seek::Exception';
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
-has 'criterion';
-has 'separator';
-has 'subject';
-has 'target';
+has 'criterion', is => 'ro';
+has 'separator', is => 'ro';
+has 'subject',   is => 'ro';
+has 'target',    is => 'ro';
 
-has 'is_array';
-has 'is_ending';
-has 'is_hash';
-has 'is_match';
+has 'is_array',  is => 'ro';
+has 'is_ending', is => 'ro';
+has 'is_hash',   is => 'ro';
+has 'is_match',  is => 'ro';
 
 sub _build_message {
     my $self = shift;
@@ -51,7 +46,7 @@ Data::Seek::Exception::RootUnknown - Data::Seek Unknown Root Exception Class
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -113,8 +108,6 @@ True is the node is, during the exception being thrown, a hash reference.
 
 True is the node has, during the exception being thrown, corresponding data.
 
-=encoding utf8
-
 =head1 AUTHOR
 
 Al Newkirk <anewkirk@ana.io>
