@@ -1,29 +1,25 @@
 # ABSTRACT: Data::Seek Search Result Class
 package Data::Seek::Search::Result;
 
-use 5.10.0;
-use strict;
-use warnings;
-
 use Data::Seek::Data;
 use Data::Seek::Exception;
 use Data::Seek::Search;
 
-use Mo 'builder';
+use Data::Object::Class;
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
-has 'datasets',
-    builder => '_build_datasets';
+has 'datasets' => (
+    is      => 'ro',
+    default => sub { shift->search->perform },
+    lazy    => 1
+);
 
-sub _build_datasets {
-    my $self = shift;
-    my $search = $self->search;
-    return $search->perform;
-}
-
-has 'search',
-    default => sub { Data::Seek::Search->new };
+has 'search' => (
+    is      => 'ro',
+    default => sub { Data::Seek::Search->new },
+    lazy    => 1
+);
 
 sub data {
     my $self = shift;
@@ -78,7 +74,7 @@ Data::Seek::Search::Result - Data::Seek Search Result Class
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -128,8 +124,6 @@ keys/paths matching the criteria used in the search.
 Produce a data structure, i.e. an array reference, comprised of only the values
 matching the criteria used in the search.
 
-=encoding utf8
-
 =head1 AUTHOR
 
 Al Newkirk <anewkirk@ana.io>
